==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/StorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies the storage settings for the virtual machine disks.
 * @property disks Gets or sets the list of virtual disks associated with the virtual machine.
 */
public data class StorageProfileArgs(
    public val disks: Output<List<VirtualDiskArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs.builder()
            .disks(
                disks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [StorageProfileArgs].
 */
@PulumiTagMarker
public class StorageProfileArgsBuilder internal constructor() {
    private var disks: Output<List<VirtualDiskArgs>>? = null

    /**
     * @param value Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("tycdchevymoklwfa")
    public suspend fun disks(`value`: Output<List<VirtualDiskArgs>>) {
        this.disks = value
    }

    @JvmName("yciyqyykkletotwg")
    public suspend fun disks(vararg values: Output<VirtualDiskArgs>) {
        this.disks = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("qjkwhhgiigciwtuq")
    public suspend fun disks(values: List<Output<VirtualDiskArgs>>) {
        this.disks = Output.all(values)
    }

    /**
     * @param value Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("yodvydftuuxxesnh")
    public suspend fun disks(`value`: List<VirtualDiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("fgbwtymlscqdmqaw")
    public suspend fun disks(argument: List<suspend VirtualDiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { VirtualDiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("lfinhjhtcwbhkpaw")
    public suspend fun disks(vararg argument: suspend VirtualDiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { VirtualDiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("yhvijjcyvqkpwnop")
    public suspend fun disks(argument: suspend VirtualDiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualDiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param values Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("wrcajvlnlhuiobwp")
    public suspend fun disks(vararg values: VirtualDiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    internal fun build(): StorageProfileArgs = StorageProfileArgs(
        disks = disks,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/connectedvmwarevsphere/kotlin/inputs/StorageProfileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.connectedvmwarevsphere.kotlin.inputs

import com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Specifies the storage settings for the virtual machine disks.
 * @property disks Gets or sets the list of virtual disks associated with the virtual machine.
 */
public data class StorageProfileArgs(
    public val disks: Output<List<VirtualDiskArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs> {
    override fun toJava(): com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs =
        com.pulumi.azurenative.connectedvmwarevsphere.inputs.StorageProfileArgs.builder()
            .disks(
                disks?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [StorageProfileArgs].
 */
@PulumiTagMarker
public class StorageProfileArgsBuilder internal constructor() {
    private var disks: Output<List<VirtualDiskArgs>>? = null

    /**
     * @param value Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("lofwsjowosbufcwp")
    public suspend fun disks(`value`: Output<List<VirtualDiskArgs>>) {
        this.disks = value
    }

    @JvmName("vglcadygegxntndv")
    public suspend fun disks(vararg values: Output<VirtualDiskArgs>) {
        this.disks = Output.all(values.asList())
    }

    /**
     * @param values Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("tojhwnxiirouclyx")
    public suspend fun disks(values: List<Output<VirtualDiskArgs>>) {
        this.disks = Output.all(values)
    }

    /**
     * @param value Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("pttjwqrbkkklecsq")
    public suspend fun disks(`value`: List<VirtualDiskArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("rwdpjuvrmatpxcah")
    public suspend fun disks(argument: List<suspend VirtualDiskArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { VirtualDiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("buxcifhycurmhcvs")
    public suspend fun disks(vararg argument: suspend VirtualDiskArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { VirtualDiskArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param argument Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("evtxyvwboweioivm")
    public suspend fun disks(argument: suspend VirtualDiskArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualDiskArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.disks = mapped
    }

    /**
     * @param values Gets or sets the list of virtual disks associated with the virtual machine.
     */
    @JvmName("qonvrieyupncorqa")
    public suspend fun disks(vararg values: VirtualDiskArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.disks = mapped
    }

    internal fun build(): StorageProfileArgs = StorageProfileArgs(
        disks = disks,
    )
}
